@@ -21,7 +21,7 @@ from VeraGridEngine.Devices.multi_circuit import MultiCircuit
 import VeraGridEngine.Devices as dev
 from VeraGridEngine.Simulations.PowerFlow.power_flow_options import PowerFlowOptions
 from VeraGridEngine.Simulations.PowerFlow.power_flow_results import PowerFlowResults
-from VeraGridEngine import TapModuleControl, TapPhaseControl
+from VeraGridEngine.enumerations import TapModuleControl, TapPhaseControl
 from VeraGridEngine.enumerations import SolverType
 from VeraGridEngine.DataStructures.numerical_circuit import NumericalCircuit
 
@@ -676,7 +676,7 @@ def convert_bus(elm: dev.Bus, n_time: int,
     :return:
     """
     bus = pg.Bus(nt=n_time,
-                 name=elm.name,
+                 name=str(elm.name),
                  idtag=elm.idtag,
                  code=str(elm.code),
                  Vnom=elm.Vnom,
