@@ -1,12 +1,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at https://mozilla.org/MPL/2.0/.
+# file, You can obtain one at https://mozilla.org/MPL/2.0/.  
 # SPDX-License-Identifier: MPL-2.0
 
-from __future__ import annotations
-
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.identified_object import IdentifiedObject
+from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.identified_object import IdentifiedObject
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -14,9 +12,9 @@ class OperationalLimit(IdentifiedObject):
 	def __init__(self, rdfid='', tpe='OperationalLimit'):
 		IdentifiedObject.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.operational_limit_set import OperationalLimitSet
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.operational_limit_set import OperationalLimitSet
 		self.OperationalLimitSet: OperationalLimitSet | None = None
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.operational_limit_type import OperationalLimitType
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.operational_limit_type import OperationalLimitType
 		self.OperationalLimitType: OperationalLimitType | None = None
 
 		self.register_property(
@@ -24,7 +22,7 @@ class OperationalLimit(IdentifiedObject):
 			class_type=OperationalLimitSet,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The limit set to which the limit values belong.''',
+			description='''Values of equipment limits.''',
 			profiles=[]
 		)
 		self.register_property(
