@@ -12,7 +12,7 @@ class RatioTapChangerTablePoint(Base):
 	def __init__(self, rdfid, tpe, resources=list(), class_replacements=dict()):
 		Base.__init__(self, rdfid=rdfid, tpe=tpe, resources=resources, class_replacements=class_replacements)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.ratio_tap_changer_table import RatioTapChangerTable
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.ratio_tap_changer_table import RatioTapChangerTable
 		self.RatioTapChangerTable: RatioTapChangerTable | None = None
 
 		self.register_property(
@@ -20,6 +20,6 @@ class RatioTapChangerTablePoint(Base):
 			class_type=RatioTapChangerTable,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''Table of this point.''',
+			description='''Points of this table.''',
 			profiles=[]
 		)
