@@ -1,10 +1,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at https://mozilla.org/MPL/2.0/.
+# file, You can obtain one at https://mozilla.org/MPL/2.0/.  
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.basic_interval_schedule import BasicIntervalSchedule
+from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.basic_interval_schedule import BasicIntervalSchedule
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType, UnitSymbol
 
 
@@ -29,6 +29,6 @@ class RegularIntervalSchedule(BasicIntervalSchedule):
 			class_type=datetime.datetime,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The time for the last time point.  The value can be a time of day, not a specific date.''',
+			description='''The time for the last time point.''',
 			profiles=[]
 		)
