@@ -1,12 +1,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at https://mozilla.org/MPL/2.0/.  
+# file, You can obtain one at https://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 
-from __future__ import annotations
-
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.identified_object import IdentifiedObject
+from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.identified_object import IdentifiedObject
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -14,9 +12,9 @@ class ReportingGroup(IdentifiedObject):
 	def __init__(self, rdfid='', tpe='ReportingGroup'):
 		IdentifiedObject.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.bus_name_marker import BusNameMarker
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.bus_name_marker import BusNameMarker
 		self.BusNameMarker: BusNameMarker | None = None
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.topological_node import TopologicalNode
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.topological_node import TopologicalNode
 		self.TopologicalNode: TopologicalNode | None = None
 
 		self.register_property(
@@ -24,7 +22,7 @@ class ReportingGroup(IdentifiedObject):
 			class_type=BusNameMarker,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The bus name markers that belong to this reporting group.''',
+			description='''The reporting group to which this bus name marker belongs.''',
 			profiles=[]
 		)
 		self.register_property(
@@ -32,6 +30,6 @@ class ReportingGroup(IdentifiedObject):
 			class_type=TopologicalNode,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The topological nodes that belong to the reporting group.''',
+			description='''The reporting group to which the topological node belongs.''',
 			profiles=[]
 		)
