@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.operational_limit import OperationalLimit
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.operational_limit import OperationalLimit
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType, UnitSymbol
 
 
@@ -12,8 +12,17 @@ class ActivePowerLimit(OperationalLimit):
 	def __init__(self, rdfid='', tpe='ActivePowerLimit'):
 		OperationalLimit.__init__(self, rdfid, tpe)
 
+		self.normalValue: float = None
 		self.value: float = None
 
+		self.register_property(
+			name='normalValue',
+			class_type=float,
+			multiplier=UnitMultiplier.M,
+			unit=UnitSymbol.W,
+			description='''Product of RMS value of the voltage and the RMS value of the in-phase component of the current.''',
+			profiles=[]
+		)
 		self.register_property(
 			name='value',
 			class_type=float,
