@@ -3,8 +3,10 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 
+from __future__ import annotations
+
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.acdc_terminal import ACDCTerminal
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.acdc_terminal import ACDCTerminal
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,9 +14,9 @@ class DCBaseTerminal(ACDCTerminal):
 	def __init__(self, rdfid='', tpe='DCBaseTerminal'):
 		ACDCTerminal.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_node import DCNode
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_node import DCNode
 		self.DCNode: DCNode | None = None
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_topological_node import DCTopologicalNode
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_topological_node import DCTopologicalNode
 		self.DCTopologicalNode: DCTopologicalNode | None = None
 
 		self.register_property(
@@ -22,7 +24,7 @@ class DCBaseTerminal(ACDCTerminal):
 			class_type=DCNode,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''None''',
+			description='''The DC connectivity node to which this DC base terminal connects with zero impedance.''',
 			profiles=[]
 		)
 		self.register_property(
@@ -30,6 +32,6 @@ class DCBaseTerminal(ACDCTerminal):
 			class_type=DCTopologicalNode,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''See association end TopologicalNode.Terminal.''',
+			description='''See association end Terminal.TopologicalNode.''',
 			profiles=[]
 		)
