@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.equipment_container import EquipmentContainer
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.equipment_container import EquipmentContainer
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,9 +12,9 @@ class DCEquipmentContainer(EquipmentContainer):
 	def __init__(self, rdfid='', tpe='DCEquipmentContainer'):
 		EquipmentContainer.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_node import DCNode
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_node import DCNode
 		self.DCNodes: DCNode | None = None
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_topological_node import DCTopologicalNode
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_topological_node import DCTopologicalNode
 		self.DCTopologicalNode: DCTopologicalNode | None = None
 
 		self.register_property(
@@ -22,7 +22,7 @@ class DCEquipmentContainer(EquipmentContainer):
 			class_type=DCNode,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''None''',
+			description='''The DC nodes contained in the DC equipment container.''',
 			profiles=[]
 		)
 		self.register_property(
@@ -30,6 +30,6 @@ class DCEquipmentContainer(EquipmentContainer):
 			class_type=DCTopologicalNode,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''None''',
+			description='''The topological nodes which belong to this connectivity node container.''',
 			profiles=[]
 		)
