@@ -3,8 +3,10 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 
+from __future__ import annotations
+
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_base_terminal import DCBaseTerminal
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_base_terminal import DCBaseTerminal
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,7 +14,7 @@ class DCTerminal(DCBaseTerminal):
 	def __init__(self, rdfid='', tpe='DCTerminal'):
 		DCBaseTerminal.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_conducting_equipment import DCConductingEquipment
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_conducting_equipment import DCConductingEquipment
 		self.DCConductingEquipment: DCConductingEquipment | None = None
 
 		self.register_property(
@@ -20,6 +22,6 @@ class DCTerminal(DCBaseTerminal):
 			class_type=DCConductingEquipment,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''None''',
+			description='''An DC  terminal belong to a DC conducting equipment.''',
 			profiles=[]
 		)
