@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.identified_object import IdentifiedObject
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.identified_object import IdentifiedObject
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,7 +12,7 @@ class DCTopologicalIsland(IdentifiedObject):
 	def __init__(self, rdfid='', tpe='DCTopologicalIsland'):
 		IdentifiedObject.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.dc_topological_node import DCTopologicalNode
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.dc_topological_node import DCTopologicalNode
 		self.DCTopologicalNodes: DCTopologicalNode | None = None
 
 		self.register_property(
@@ -20,6 +20,6 @@ class DCTopologicalIsland(IdentifiedObject):
 			class_type=DCTopologicalNode,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''None''',
+			description='''The DC topological nodes in a DC topological island.''',
 			profiles=[]
 		)
