@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.identified_object import IdentifiedObject
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.identified_object import IdentifiedObject
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,7 +12,7 @@ class EnergySchedulingType(IdentifiedObject):
 	def __init__(self, rdfid='', tpe='EnergySchedulingType'):
 		IdentifiedObject.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.energy_source import EnergySource
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.energy_source import EnergySource
 		self.EnergySource: EnergySource | None = None
 
 		self.register_property(
@@ -20,6 +20,6 @@ class EnergySchedulingType(IdentifiedObject):
 			class_type=EnergySource,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''Energy Scheduling Type of an Energy Source''',
+			description='''Energy Source of a particular Energy Scheduling Type.''',
 			profiles=[]
 		)
