@@ -4,13 +4,13 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.identified_object import IdentifiedObject
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.io_point import IOPoint
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType, UnitSymbol
 
 
-class MeasurementValue(IdentifiedObject):
+class MeasurementValue(IOPoint):
 	def __init__(self, rdfid='', tpe='MeasurementValue'):
-		IdentifiedObject.__init__(self, rdfid, tpe)
+		IOPoint.__init__(self, rdfid, tpe)
 
 		import datetime
 		self.timeStamp: datetime.datetime | None = None
@@ -21,7 +21,7 @@ class MeasurementValue(IdentifiedObject):
 			class_type=datetime.datetime,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The time when the value was last updated''',
+			description='''The time when the value was last updated.''',
 			profiles=[]
 		)
 		self.register_property(
