@@ -3,8 +3,10 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 
+from __future__ import annotations
+
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.tap_changer import TapChanger
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.tap_changer import TapChanger
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,7 +14,7 @@ class PhaseTapChanger(TapChanger):
 	def __init__(self, rdfid='', tpe='PhaseTapChanger'):
 		TapChanger.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.transformer_end import TransformerEnd
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.transformer_end import TransformerEnd
 		self.TransformerEnd: TransformerEnd | None = None
 
 		self.register_property(
@@ -20,6 +22,6 @@ class PhaseTapChanger(TapChanger):
 			class_type=TransformerEnd,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''Phase tap changer associated with this transformer end.''',
+			description='''Transformer end to which this phase tap changer belongs.''',
 			profiles=[]
 		)
