@@ -1,10 +1,10 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at https://mozilla.org/MPL/2.0/.  
+# file, You can obtain one at https://mozilla.org/MPL/2.0/.
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.identified_object import IdentifiedObject
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.identified_object import IdentifiedObject
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,9 +12,9 @@ class RatioTapChangerTable(IdentifiedObject):
 	def __init__(self, rdfid='', tpe='RatioTapChangerTable'):
 		IdentifiedObject.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.ratio_tap_changer import RatioTapChanger
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.ratio_tap_changer import RatioTapChanger
 		self.RatioTapChanger: RatioTapChanger | None = None
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.ratio_tap_changer_table_point import RatioTapChangerTablePoint
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.ratio_tap_changer_table_point import RatioTapChangerTablePoint
 		self.RatioTapChangerTablePoint: RatioTapChangerTablePoint | None = None
 
 		self.register_property(
@@ -22,7 +22,7 @@ class RatioTapChangerTable(IdentifiedObject):
 			class_type=RatioTapChanger,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The tap ratio table for this ratio  tap changer.''',
+			description='''The ratio tap changer of this tap ratio table.''',
 			profiles=[]
 		)
 		self.register_property(
@@ -30,6 +30,6 @@ class RatioTapChangerTable(IdentifiedObject):
 			class_type=RatioTapChangerTablePoint,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''Table of this point.''',
+			description='''Points of this table.''',
 			profiles=[]
 		)
