@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from VeraGridEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.curve import Curve
+from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.curve import Curve
 from VeraGridEngine.IO.cim.cgmes.cgmes_enums import CgmesProfileType
 
 
@@ -12,9 +12,9 @@ class ReactiveCapabilityCurve(Curve):
 	def __init__(self, rdfid='', tpe='ReactiveCapabilityCurve'):
 		Curve.__init__(self, rdfid, tpe)
 
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.equivalent_injection import EquivalentInjection
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.equivalent_injection import EquivalentInjection
 		self.EquivalentInjection: EquivalentInjection | None = None
-		from VeraGridEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.synchronous_machine import SynchronousMachine
+		from VeraGridEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.synchronous_machine import SynchronousMachine
 		self.InitiallyUsedBySynchronousMachines: SynchronousMachine | None = None
 
 		self.register_property(
@@ -22,7 +22,7 @@ class ReactiveCapabilityCurve(Curve):
 			class_type=EquivalentInjection,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The reactive capability curve used by this equivalent injection.''',
+			description='''The equivalent injection using this reactive capability curve.''',
 			profiles=[]
 		)
 		self.register_property(
@@ -30,6 +30,6 @@ class ReactiveCapabilityCurve(Curve):
 			class_type=SynchronousMachine,
 			multiplier=UnitMultiplier.none,
 			unit=UnitSymbol.none,
-			description='''The default reactive capability curve for use by a synchronous machine.''',
+			description='''Synchronous machines using this curve as default.''',
 			profiles=[]
 		)
