@@ -231,13 +231,11 @@ class NodalCapacityTimeSeriesDriver(TimeSeriesDriverTemplate):
             # run opf
             res = run_nonlinear_opf(grid=self.grid,
                                     opf_options=self.opf_options,
-                                    pf_options=self.pf_options,
                                     t_idx=t,
                                     # for the first power flow, use the given strategy
                                     # for the successive ones, use the previous solution
-                                    pf_init=self.opf_options.ips_init_with_pf if it == 0 else True,
-                                    Sbus_pf0=self.results.Sbus[it - 1, :] if it > 0 else None,
-                                    voltage_pf0=self.results.voltage[it - 1, :] if it > 0 else None,
+                                    # Sbus_pf0=self.results.Sbus[it - 1, :] if it > 0 else None,
+                                    # voltage_pf0=self.results.voltage[it - 1, :] if it > 0 else None,
                                     optimize_nodal_capacity=True,
                                     nodal_capacity_sign=self.options.nodal_capacity_sign,
                                     capacity_nodes_idx=self.options.capacity_nodes_idx,
