@@ -235,9 +235,9 @@ class OptimalPowerFlowDriver(TimeSeriesDriverTemplate):
 
             res = run_nonlinear_opf(grid=self.grid,
                                     opf_options=self.options,
-                                    pf_options=self.pf_options,
                                     t_idx=None,
                                     logger=self.logger)
+
             Sbase = self.grid.Sbase
             self.results.voltage = res.V
             self.results.Sbus = res.S * Sbase
@@ -258,6 +258,8 @@ class OptimalPowerFlowDriver(TimeSeriesDriverTemplate):
             self.results.hvdc_Pf = res.hvdc_Pf
             self.results.hvdc_loading = res.hvdc_loading
             self.results.converged = res.converged
+            self.results.error = res.error
+            self.results.non_linear = True
 
             msg = "Interior point solver"
             self.logger.add_info(msg=msg, device="Error", value=res.error, expected_value=self.options.ips_tolerance)
