@@ -165,7 +165,9 @@ class OptimalPowerFlowResults(ResultsTemplate):
         self.contingency_indices_list = list()  # [(t, m, c), ...]
         self.contingency_flows_slacks_list = list()
 
+        self.non_linear = False
         self.converged = False
+        self.error = 0.0
 
         # vars for the inter-area computation
         self.F = F
@@ -230,7 +232,9 @@ class OptimalPowerFlowResults(ResultsTemplate):
         self.register(name='fluid_path_flow', tpe=Vec)
         self.register(name='fluid_injection_flow', tpe=Vec)
 
+        self.register(name='non_linear', tpe=bool)
         self.register(name='converged', tpe=bool)
+        self.register(name='error', tpe=float)
         self.register(name='contingency_flows_list', tpe=list)
         self.register(name='contingency_indices_list', tpe=list)
         self.register(name='contingency_flows_slacks_list', tpe=list)
@@ -249,38 +253,75 @@ class OptimalPowerFlowResults(ResultsTemplate):
         Get a DataFrame with the buses results
         :return: DataFrame
         """
-        return pd.DataFrame(data={'Va': np.angle(self.voltage, deg=True),
-                                  'P': self.Sbus.real,
-                                  'Shadow price': self.bus_shadow_prices},
-                            index=self.bus_names)
+        if self.non_linear:
+            return pd.DataFrame(data={'Vm': np.abs(self.voltage),
+                                      'Va': np.angle(self.voltage, deg=True),
+                                      'P': self.Sbus.real,
+                                      'Q': self.Sbus.imag,
+                                      'Shadow price': self.bus_shadow_prices},
+                                index=self.bus_names)
+        else:
+            return pd.DataFrame(data={'Va': np.angle(self.voltage, deg=True),
+                                      'P': self.Sbus.real,
+                                      'Shadow price': self.bus_shadow_prices},
+                                index=self.bus_names)
 
     def get_branch_df(self) -> pd.DataFrame:
         """
         Get a DataFrame with the branches results
         :return: DataFrame
         """
-        return pd.DataFrame(data={'Pf': self.Sf.real,
-                                  'Pt': self.St.real,
-                                  'Tap angle': self.phase_shift,
-                                  'loading': self.loading.real * 100.0},
-                            index=self.branch_names)
+        if self.non_linear:
+            return pd.DataFrame(data={'Pf': self.Sf.real,
+                                      'Pt': self.St.real,
+                                      'Qf': self.Sf.imag,
+                                      'Qt': self.St.imag,
+                                      'Tap angle': self.phase_shift,
+                                      'loading': self.loading.real * 100.0},
+                                index=self.branch_names)
+        else:
+            return pd.DataFrame(data={'Pf': self.Sf.real,
+                                      'Pt': self.St.real,
+                                      'Tap angle': self.phase_shift,
+                                      'loading': self.loading.real * 100.0},
+                                index=self.branch_names)
 
     def get_gen_df(self) -> pd.DataFrame:
         """
         Get a DataFrame with the generator results
         :return: DataFrame
         """
-        return pd.DataFrame(data={'P': self.generator_power,
-                                  'P shedding': self.generator_shedding},
-                            index=self.generator_names)
+        if self.non_linear:
+            return pd.DataFrame(
+                data={
+                    'P': self.generator_power,
+                    'Q': self.generator_reactive_power,
+                    'P shedding': self.generator_shedding,
+                },
+                index=self.generator_names
+            )
+        else:
+            return pd.DataFrame(
+                data={'P': self.generator_power,
+                      'P shedding': self.generator_shedding},
+                index=self.generator_names
+            )
 
     def get_batt_df(self) -> pd.DataFrame:
         """
         Get a DataFrame with the battery results
         :return: DataFrame
         """
-        return pd.DataFrame(data={'P': self.generator_power},
-                            index=self.battery_power)
+        if self.non_linear:
+            return pd.DataFrame(
+                data={
+                    'P': self.battery_power,
+                },
+                index=self.battery_names
+            )
+        else:
+            return pd.DataFrame(data={'P': self.battery_power},
+                                index=self.battery_names)
 
     def get_hvdc_df(self) -> pd.DataFrame:
         """
