@@ -219,7 +219,7 @@ class SolverType(Enum):
 
     NR = 'Newton Raphson'
     GAUSS = 'Gauss-Seidel'
-    LU = 'Decoupled-LU Decomposition'
+    Decoupled_LU = 'Decoupled-LU Decomposition'
     GN = "Gauss-Newton"
     Linear = 'Linear'
     HELM = 'Holomorphic Embedding'
